@@ -11,20 +11,30 @@ class BaseService():
 
 
 class MessagingService(BaseService):
-    def send_message(self, app_mxit_id, target_user_ids, message='', contains_markup=True, scope='message/send'):
+    def send_message(self, app_mxit_id, target_user_ids, message='', contains_markup=True,
+                     spool=None, spool_timeout=None, links=None, scope='message/send'):
         """
         Send a message (from a Mxit app) to a list of Mxit users
         """
 
+        data = {
+            'From': app_mxit_id,
+            'To': ",".join(target_user_ids),
+            'Body': message,
+            'ContainsMarkup': contains_markup
+        }
+
+        if spool:
+            data['Spool'] = spool
+        if spool_timeout:
+            data['SpoolTimeOut'] = spool_timeout
+        if links:
+            data['Links'] = links
+
         return _post(
             token=self.oauth.get_app_token(scope),
             uri='/message/send',
-            data={
-                'From': app_mxit_id,
-                'To': ",".join(target_user_ids),
-                'Body': message,
-                'ContainsMarkup': contains_markup
-            }
+            data=data
         )
 
     def send_user_to_user_message(self, from_user_id, target_user_ids, message='', contains_markup=True,
@@ -43,6 +53,19 @@ class MessagingService(BaseService):
             }
         )
 
+    def create_redirect_link(self, create_temporary_contact, target_service, text,
+                             add_to_back_history=None, parameters=None):
+        data = {
+            'CreateTemporaryContact': create_temporary_contact,
+            'TargetService': target_service,
+            'Text': text
+        }
+        if add_to_back_history:
+            data['AddToBackHistory'] = add_to_back_history;
+        if parameters:
+            data['Parameters'] = parameters;
+        return data
+
 
 class UserService(BaseService):
     def get_user_id(self, mxit_id, scope='profile/public'):
@@ -527,4 +550,4 @@ def _delete(token, uri, content_type='application/json', api_endpoint=settings.A
         raise MxitAPIException("Unexpected HTTP Status: %s" % r.status_code,
                                {'response': response, 'code': r.status_code})
 
-    return response
\ No newline at end of file
+    return response
